measuretools.measure_to_one_line_input_string
=============================================

.. autofunction:: abjad.tools.measuretools.measure_to_one_line_input_string.measure_to_one_line_input_string
